@@ -73,6 +73,7 @@ use Exporter;
 %EXPORT_TAGS = (all => [qw(decode_mimewords
 			   encode_mimeword
 			   encode_mimewords
+                           unmime
 			   )]);
 Exporter::export_ok_tags('all');
 
@@ -92,7 +93,7 @@ use MIME::QuotedPrint;
 #------------------------------
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = substr q$Revision: 5.207 $, 10;
+$VERSION = substr q$Revision: 5.403 $, 10;
 
 ### Nonprintables (controls + x7F + 8bit):
 my $NONPRINT = "\\x00-\\x1F\\x7F-\\xFF"; 
@@ -130,7 +131,7 @@ sub _decode_B {
 #     Private: used by _decode_header() to decode "B" encoding.
 sub _encode_B {
     my $str = shift;
-    encode_base64($str);
+    encode_base64($str, '');
 }
 
 
@@ -234,6 +235,30 @@ sub decode_mimewords {
 
 #------------------------------
 
+=item unmime STRING
+
+I<Function, exported.>
+Unencode a string if it I<looks> like it I<might> contain encoded words.
+For example, assume this header:
+
+    Subject: Here is =?US-ASCII?Q?=46=4F=4F.doc?=
+
+You can access it in either of two ways:
+
+    $subj =        $head->get("subject");   ### gets: "Here is =?....?="
+    $subj = unmime $head->get("subject");   ### gets: "Here is FOO.doc"
+
+=cut
+
+sub unmime {
+    my ($value) = @_;
+    ((defined($value) && ($value =~ m{=\?.*?\?.*\?=}s))
+     ?  scalar(decode_mimewords($value))
+     :  $value);
+}
+
+#------------------------------
+
 =item encode_mimeword RAW, [ENCODING], [CHARSET]
 
 Encode a single RAW "word" that has unsafe characters.
@@ -341,7 +366,7 @@ Thanks also to...
 
 =head1 VERSION
 
-$Revision: 5.207 $ $Date: 2000/09/21 05:54:15 $
+$Revision: 5.403 $ $Date: 2000/11/04 19:54:48 $
 
 =cut
 
